@@ -69,7 +69,7 @@ def obj_to_bytes(obj):
         try:
             obj = str2html(json.dumps(obj, indent=2))
         except:
-            obj = str(obj)
+            obj = str2html(str(obj))
         obj = obj.encode()
     return obj
 
